@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 3269 2007-11-29 16:28:17Z wwalker $"
-__version__   = "$Revision: 3269 $"
-__date__      = "$Date: 2007-11-29 11:28:17 -0500 (Thu, 29 Nov 2007) $"
+__id__        = "$Id: orca_console_prefs.py 3806 2008-04-04 20:57:48Z richb $"
+__version__   = "$Revision: 3806 $"
+__date__      = "$Date: 2008-04-04 16:57:48 -0400 (Fri, 04 Apr 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -427,12 +427,14 @@ def logoutUser():
                         False,                 # Fast
                         True)                  # All apps save state
 
-def showPreferencesUI():
+def showPreferencesUI(commandLineSettings):
     """Uses the console to query the user for Orca preferences."""
 
     prefsDict = {}
 
-    if not setupSpeech(prefsDict):
+    if ("enableSpeech" in commandLineSettings and \
+        not commandLineSettings["enableSpeech"]) or \
+       (not setupSpeech(prefsDict)):
         prefsDict["enableSpeech"]     = False
         prefsDict["enableEchoByWord"] = False
         prefsDict["enableKeyEcho"]    = False
