@@ -19,9 +19,9 @@
 
 """Displays a GUI for the user to quit Orca."""
 
-__id__        = "$Id: orca_quit.py 3077 2007-10-17 16:32:55Z richb $"
-__version__   = "$Revision: 3077 $"
-__date__      = "$Date: 2007-10-17 12:32:55 -0400 (Wed, 17 Oct 2007) $"
+__id__        = "$Id: orca_quit.py 3286 2007-11-29 21:29:08Z richb $"
+__version__   = "$Revision: 3286 $"
+__date__      = "$Date: 2007-11-29 16:29:08 -0500 (Thu, 29 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -39,12 +39,12 @@ import settings
 
 OS = None
 
-class orcaQuitGUI(orca_glade.GladeWrapper):
+class OrcaQuitGUI(orca_glade.GladeWrapper):
 
-    def _init(self):
+    def init(self):
         pass
 
-    def _showGUI(self):
+    def showGUI(self):
         """Show the Orca quit GUI dialog. This assumes that the GUI has 
         already been created.
         """
@@ -76,7 +76,7 @@ class orcaQuitGUI(orca_glade.GladeWrapper):
 
         self.get_widget("quitDialog").hide()
         if settings.showMainWindow:
-            orca._showMainWindowGUI()
+            orca.showMainWindowGUI()
 
     def quitYesButtonClicked(self, widget):
         """Signal handler for the "clicked" signal for the quitYesButton
@@ -112,10 +112,10 @@ def showQuitUI():
                                  platform.package,
                                  "glade",
                                  "orca-quit.glade")
-        OS = orcaQuitGUI(gladeFile, "quitDialog")
-        OS._init()
+        OS = OrcaQuitGUI(gladeFile, "quitDialog")
+        OS.init()
 
-    OS._showGUI()
+    OS.showGUI()
 
 def main():
     locale.setlocale(locale.LC_ALL, '')
