@@ -27,9 +27,9 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: gaim.py 3808 2008-04-04 23:01:33Z richb $"
-__version__   = "$Revision: 3808 $"
-__date__      = "$Date: 2008-04-04 19:01:33 -0400 (Fri, 04 Apr 2008) $"
+__id__        = "$Id: gaim.py 3839 2008-04-19 17:13:42Z richb $"
+__version__   = "$Revision: 3839 $"
+__date__      = "$Date: 2008-04-19 13:13:42 -0400 (Sat, 19 Apr 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -751,6 +751,66 @@ class Script(default.Script):
 
         return rv, start, end
 
+    def isBuddyListEvent(self, event):
+        """If pidgin gets a status changed message for one of the users
+        buddies then just ignore it. See bug #525644 for more details.
+
+        Arguments:
+        - event: the Event
+
+        Return an indication of whether this is a buddy list event.
+        """
+
+        isBuddyListEvent = False
+        rolesList = [pyatspi.ROLE_TABLE_CELL, \
+                     pyatspi.ROLE_TABLE_CELL, \
+                     pyatspi.ROLE_TREE_TABLE, \
+                     pyatspi.ROLE_SCROLL_PANE, \
+                     pyatspi.ROLE_FILLER, \
+                     pyatspi.ROLE_PAGE_TAB, \
+                     pyatspi.ROLE_PAGE_TAB_LIST]
+        if self.isDesiredFocusedItem(event.source, rolesList):
+            isBuddyListEvent = True
+
+        return isBuddyListEvent
+
+    def onTextDeleted(self, event):
+        """Called whenever text is deleted from an object.
+
+        Arguments:
+        - event: the Event
+        """
+
+        if self.isBuddyListEvent(event):
+            return
+        else:
+            default.Script.onTextDeleted(self, event)
+
+    def onNameChanged(self, event):
+        """Called whenever a property on an object changes.
+
+        Arguments:
+        - event: the Event
+        """
+
+        if self.isBuddyListEvent(event):
+            return
+        else:
+            default.Script.onNameChanged(self, event)
+
+    def onValueChanged(self, event):
+        """Called whenever an object's value changes.  Currently, the
+        value changes for non-focused objects are ignored.
+
+        Arguments:
+        - event: the Event
+        """
+
+        if self.isBuddyListEvent(event):
+            return
+        else:
+            default.Script.onValueChanged(self, event)
+
     def onTextInserted(self, event):
         """Called whenever text is inserted into one of Gaim's text
         objects.  If the object is an instant message or chat, speak
@@ -761,6 +821,9 @@ class Script(default.Script):
         - event: the text inserted Event
         """
 
+        if self.isBuddyListEvent(event):
+            return
+
         chatRoomTab = self.getChatRoomTab(event.source)
         if not chatRoomTab:
             default.Script.onTextInserted(self, event)
